@@ -35,7 +35,7 @@ from translate.misc import quote
 from translate.misc.multistring import multistring
 from translate.misc.xml_helpers import setXMLspace
 from translate.storage.base import TranslationStore
-from translate.storage.csvl10n import csv
+from translate.storage.csvl10n import csv, csvunit
 from translate.storage.jsonl10n import BaseJsonUnit, JsonFile
 from translate.storage.lisa import LISAfile
 from translate.storage.po import pofile, pounit
@@ -65,7 +65,7 @@ from weblate.utils.state import STATE_APPROVED, STATE_FUZZY, STATE_TRANSLATED
 
 LOCATIONS_RE = re.compile(r"^([+-]|.*, [+-]|.*:[+-])")
 PO_DOCSTRING_LOCATION = re.compile(r":docstring of [a-zA-Z0-9._]+:[0-9]+")
-SUPPORTS_FUZZY = (pounit, tsunit)
+SUPPORTS_FUZZY = (pounit, tsunit, csvunit)
 XLIFF_FUZZY_STATES = {"new", "needs-translation", "needs-adaptation", "needs-l10n"}
 
 
@@ -209,7 +209,8 @@ class KeyValueUnit(TTKitUnit):
         """Set translation unit target."""
         super().set_target(target)
         # Propagate to value so that searializing of empty values works correctly
-        self.unit.value = self.unit.target
+        if not target:
+            self.unit.value = self.unit.target
 
 
 class TTKitFormat(TranslationFormat):
@@ -298,7 +299,7 @@ class TTKitFormat(TranslationFormat):
         return store
 
     def add_unit(self, ttkit_unit):
-        """Add new unit to underlaying store."""
+        """Add new unit to underlying store."""
         if isinstance(self.store, LISAfile):
             # LISA based stores need to know this
             self.store.addunit(ttkit_unit, new=True)
@@ -310,7 +311,7 @@ class TTKitFormat(TranslationFormat):
         self.store.serialize(handle)
 
     def save(self):
-        """Save underlaying store to disk."""
+        """Save underlying store to disk."""
         self.save_atomic(self.storefile, self.save_content)
 
     @classmethod
@@ -483,7 +484,11 @@ class TTKitFormat(TranslationFormat):
     @property
     def all_store_units(self):
         """Wrapper for all store unit filtering out obsolete."""
-        return (unit for unit in self.store.units if not unit.isobsolete())
+        return (
+            unit
+            for unit in self.store.units
+            if not unit.isobsolete() and not unit.isheader()
+        )
 
     def delete_unit(self, ttkit_unit) -> Optional[str]:
         self.store.removeunit(ttkit_unit)
@@ -724,7 +729,7 @@ class XliffUnit(TTKitUnit):
                 self.xliff_node.set("state", "new")
 
     def is_approved(self, fallback=False):
-        """Check whether unit is appoved."""
+        """Check whether unit is approved."""
         if self.unit is None:
             return fallback
         if hasattr(self.unit, "isapproved"):
@@ -778,7 +783,7 @@ class TSUnit(MonolingualIDUnit):
     def source(self):
         if self.template is None and self.mainunit.hasplural():
             # Need to apply special magic for plurals here
-            # as there is no singlular/plural in the source string
+            # as there is no singular/plural in the source string
             source = self.unit.source
             return get_string([source.replace("(s)", ""), source.replace("(s)", "s")])
         return super().source
@@ -911,6 +916,12 @@ class CSVUnit(MonolingualSimpleUnit):
     def target(self):
         return self.unescape_csv(super().target)
 
+    def is_fuzzy(self, fallback=False):
+        # Report fuzzy state only if present in the fields
+        if "fuzzy" not in self.parent.store.fieldnames:
+            return fallback
+        return super().is_fuzzy()
+
 
 class RESXUnit(TTKitUnit):
     @cached_property
@@ -1183,7 +1194,7 @@ class PropertiesBaseFormat(TTKitFormat):
         if not result:
             return False
 
-        # Accept emty file, but reject file without a delimiter.
+        # Accept empty file, but reject file without a delimiter.
         # Translate Toolkit happily parses anything into a property
         # even if there is no delimiter used in the line.
         return not self.store.units or self.store.units[0].delimiter
@@ -1318,6 +1329,7 @@ class AndroidFormat(TTKitFormat):
     autoload = ("strings*.xml", "values*.xml")
     language_format = "android"
     check_flags = ("java-format",)
+    autoaddon = {"weblate.cleanup.blank": {}}
 
 
 class DictStoreMixin:
@@ -1452,7 +1464,7 @@ class CSVFormat(TTKitFormat):
 
         # Parse file
         store = storeclass()
-        store.parse(content, sample_length=None)
+        store.parse(content, sample_length=40000)
         # Did detection of headers work?
         if store.fieldnames != ["location", "source", "target"]:
             return store
@@ -1927,3 +1939,19 @@ class FluentFormat(TTKitFormat):
         unit = super().create_unit(key, source, target)
         unit.source = unit.target
         return unit
+
+    def is_valid(self):
+        """Check whether store seems to be valid."""
+        # Workaround for https://github.com/translate/translate/issues/4615
+        for unit in self.store.units:
+            errors = unit.geterrors()
+            if errors:
+                raise ValueError(
+                    "Syntax error: {}".format(
+                        ", ".join(
+                            f"{errorname}: {errortext}"
+                            for errorname, errortext in errors.items()
+                        )
+                    )
+                )
+        return super().is_valid()
