@@ -1127,6 +1127,10 @@ $(function () {
     trigger: "@",
     requireLeadingSpace: true,
     menuShowMinLength: 2,
+    searchOpts: {
+      pre: "​",
+      post: "​",
+    },
     noMatchTemplate: function () {
       return "";
     },
@@ -1163,7 +1167,7 @@ $(function () {
     });
   });
 
-  /* Textarea higlighting */
+  /* Textarea highlighting */
   Prism.languages.none = {};
   initHighlight(document);
 
