@@ -172,7 +172,7 @@ class Formatter:
         if forbidden:
             output.append(gettext("Forbidden translation: %s") % ", ".join(forbidden))
         if nontranslatable:
-            output.append(gettext("Not-translatable: %s") % ", ".join(nontranslatable))
+            output.append(gettext("Untranslatable: %s") % ", ".join(nontranslatable))
         if translations:
             output.append(gettext("Glossary translation: %s") % ", ".join(translations))
         return "; ".join(output)
@@ -850,7 +850,7 @@ def indicate_alerts(context, obj):
                         "%(count)s strings are not being translated here.",
                         count,
                     )
-                    % {"count": count},
+                    % {"count": intcomma(count)},
                     None,
                 )
             )
