@@ -244,7 +244,7 @@ def search(base, project, unit_set, request, blank: bool = False):
 
     # Check empty search results
     if not unit_ids and not blank:
-        messages.warning(request, _("No string matched your search!"))
+        messages.warning(request, _("No strings found!"))
         return redirect(base)
 
     # Remove old search results
@@ -531,7 +531,7 @@ def translate(request, project, component, lang):  # noqa: C901
     if isinstance(search_result, HttpResponse):
         return search_result
 
-    # Get numer of results
+    # Get number of results
     num_results = len(search_result["ids"])
 
     # Search offset
@@ -550,7 +550,7 @@ def translate(request, project, component, lang):  # noqa: C901
         else:
             offset = None
         if offset is None:
-            messages.warning(request, _("No string matched your search!"))
+            messages.warning(request, _("No strings found!"))
             return redirect(obj)
     else:
         # Check boundaries
@@ -577,9 +577,6 @@ def translate(request, project, component, lang):  # noqa: C901
 
     response = None
 
-    # Any form submitted?
-    if "skip" in request.POST:
-        return redirect(next_unit_url)
     if request.method == "POST" and "merge" not in request.POST:
         if (
             "accept" in request.POST
